@@ -1,5 +1,5 @@
 from ..permissions import IsUnauthenticated
-from .serializers import OTPObtainSerializer
+from .serializers import OTPObtainSerializer, InviteSerializer, ConnectSerializer
 from .serializers import SignupSerializer
 from .serializers import SocialTokenObtainSerializer
 from .serializers import TokenObtainSerializer
@@ -30,6 +30,16 @@ class TokenViewSet(ValidationOnlyCreateViewSet):
     def signup(self, request, *args, **kwargs):
         return self.create(request, *args, **kwargs)
 
+    @action(methods=["post"], detail=False, serializer_class=InviteSerializer,
+            permission_classes=(permissions.IsAuthenticated,))
+    def invite(self, request, *args, **kwargs):
+        return self.create(request, *args, **kwargs)
+
+    @action(methods=["post"], detail=False, serializer_class=ConnectSerializer,
+            permission_classes=(permissions.IsAuthenticated,))
+    def connect(self, request, *args, **kwargs):
+        return self.create(request, *args, **kwargs)
+
     @action(
         methods=["post"],
         detail=False,
